(function(){
    'use strict';

    angular
    .module('ion-gallery', ['templates'])
    .directive('ionGallery',ionGallery);

    ionGallery.$inject = ['$ionicPlatform','ionGalleryHelper','ionGalleryConfig'];

    function ionGallery($ionicPlatform,ionGalleryHelper,ionGalleryConfig) {
        controller.$inject = ["$scope"];
        return {
            restrict: 'AE',
            scope:{
                ionGalleryItems: '=ionGalleryItems',
                ionGalleryRowSize: '=?ionGalleryRow'
            },
            controller: controller,
            link:link,
            replace:true,
            templateUrl:'app/components/ion-gallery/gallery.html'
        };

        function controller($scope){
            $scope.ionGalleryRowSize = ionGalleryHelper.getRowSize(parseInt($scope.ionGalleryRowSize) || ionGalleryConfig.row_size, $scope.ionGalleryItems.length);
            $scope.actionLabel = ionGalleryConfig.action_label;

            var _drawGallery = function(){
                var rs = ionGalleryHelper.buildGallery($scope.ionGalleryItems,$scope.ionGalleryRowSize);
                $scope.items = rs[0];
                $scope.oitems = rs[1]+rs[0];
                $scope.responsiveGrid = parseInt((1/$scope.ionGalleryRowSize)* 100);
            };

            _drawGallery();

            (function () {
                $scope.$watch(function () {
                    return $scope.ionGalleryItems.length;
                }, function (newVal, oldVal) {
                    if(newVal !== oldVal){
                        _drawGallery();

                    }
                });
            }());

        }

        function link(scope,element,attrs){
            scope.ionSliderToggle = attrs.ionGalleryToggle === 'false' ? false : ionGalleryConfig.toggle;
        }
    }
})();
(function(){
    'use strict';

    angular
    .module('ion-gallery')
    .provider('ionGalleryConfig',ionGalleryConfig);

    ionGalleryConfig.$inject = [];

    function ionGalleryConfig(){
        this.config = {
            action_label: 'Done',
            toggle: true,
            row_size: 3
        };

        this.$get = function() {
            return this.config;
        };

        this.setGalleryConfig = function(config) {
            angular.extend(this.config, this.config, config);
        };
    }

})();
(function(){
    'use strict';

    angular
    .module('ion-gallery')
    .service('ionGalleryHelper',ionGalleryHelper);

    ionGalleryHelper.$inject = ['ionGalleryConfig'];

    function ionGalleryHelper(ionGalleryConfig) {

        var _this = this;

        this.getRowSize = function(size,length){
            var rowSize;

            if(isNaN(size) === true){
                rowSize = 3;
            }
            else if(size > length){
                rowSize = length;
            }
            else if(size <= 0){
                rowSize = 1;
            }
            else{
                rowSize = size;
            }

            return rowSize;

        };

        this.buildGallery = function(items,rowSize){
            var _gallery = [];
            var row = -1;
            var col = 0;
            var first = items[0];
            var nitems = angular.copy(items);
            nitems.shift();

            for(var i=0;i<nitems.length;i++){

                if(i % rowSize === 0){
                    row++;
                    _gallery[row] = [];
                    col = 0;
                }

                if(!nitems[i].hasOwnProperty('sub')){
                    nitems[i].sub = nitems[i].title;
                }

                if(!nitems[i].hasOwnProperty('thumb')){
                    nitems[i].thumb = nitems[i].picture_url;
                }

                nitems[i].position = i;

                _gallery[row][col] = nitems[i];
                col++;
            }

            return [_gallery, first];
        };
    }
})();
(function(){
    'use strict';

    angular
    .module('ion-gallery')
    .directive('ionImageScale',ionImageScale);

    ionImageScale.$inject = [];

    function ionImageScale(){

        return {
            restrict: 'A',
            link : link
        };

        function link(scope, element, attrs) {

            var scaleImage = function(context,value) {
                if(value>0){
                    if(context.naturalHeight >= context.naturalWidth){
                        element.attr('width','100%');
                    }
                    else{
                        element.attr('height',element.parent()[0].offsetHeight+'px');
                    }
                }
            };

            element.bind("load" , function(e){
                if(element.parent()[0].offsetHeight > 0){
                    scaleImage(this,element.parent()[0].offsetHeight);
                }
                else{
                    var _this = this;
                    scope.$watch(function(){
                        return element.parent()[0].offsetHeight;
                    },function(newValue){
                        scaleImage(_this,newValue);
                    });
                }
            });
        }
    }
})();
(function(){
    'use strict';

    angular
    .module('ion-gallery')
    .directive('ionRowHeight',ionRowHeight);

    ionRowHeight.$inject = [];

    function ionRowHeight(){

        return {
            restrict: 'A',
            link : link
        };

        function link(scope, element, attrs) {

            scope.$watch(
                function(){
                    return element[0].offsetWidth;
                },
                function(newValue){
                    if(newValue > 0){
                        element.css('height',newValue * parseInt(scope.$parent.responsiveGrid)/100 + 'px');
                    }
                });
            }
        }
    })();
    (function(){
        'use strict';

        angular
        .module('ion-gallery')
        .directive('ionSlideAction',ionSlideAction);

        ionSlideAction.$inject = ['$ionicGesture','$timeout'];

        function ionSlideAction($ionicGesture, $timeout){

            return {
                restrict: 'A',
                link : link
            };

            function link(scope, element, attrs) {

                var isDoubleTapAction = false;

                var pinchZoom = function pinchZoom(){
                    scope.$emit('ZoomStarted');
                };

                var imageDoubleTapGesture = function imageDoubleTapGesture(event) {

                    isDoubleTapAction = true;

                    $timeout(function(){
                        isDoubleTapAction = false;
                        scope.$emit('DoubleTapEvent',{ 'x': event.gesture.touches[0].pageX, 'y': event.gesture.touches[0].pageY});
                    },200);
                };

                var imageTapGesture = function imageTapGesture(event) {
                    if(isDoubleTapAction === true || event.target.tagName === "A"){
                        return;
                    }
                    else{
                        $timeout(function(){
                            if(isDoubleTapAction === true || event.target.tagName === "A"){
                                return;
                            }
                            else{
                                scope.$emit('TapEvent');
                            }
                        },200);
                    }
                };

                var pinchEvent = $ionicGesture.on('pinch',pinchZoom,element);
                var doubleTapEvent = $ionicGesture.on('doubletap', function(e){imageDoubleTapGesture(e);}, element);
                var tapEvent = $ionicGesture.on('tap', imageTapGesture, element);

                scope.$on('$destroy', function() {
                    $ionicGesture.off(doubleTapEvent, 'doubletap', imageDoubleTapGesture);
                    $ionicGesture.off(tapEvent, 'tap', imageTapGesture);
                    $ionicGesture.off(pinchEvent, 'pinch', pinchZoom);
                });
            }
        }
    })();
    (function(){
        'use strict';

        angular
        .module('ion-gallery')
        .directive('ionSlider',ionSlider);

        ionSlider.$inject = ['$ionicModal','ionGalleryHelper','$ionicPlatform','$timeout','$ionicScrollDelegate', 'Restangular', '$ionicLoading', '$cordovaSocialSharing', '$cordovaInAppBrowser'];

        function ionSlider($ionicModal,ionGalleryHelper,$ionicPlatform,$timeout,$ionicScrollDelegate, Restangular, $ionicLoading, $cordovaSocialSharing, $cordovaInAppBrowser){

            controller.$inject = ["$scope"];
            return {
                restrict: 'A',
                controller: controller,
                link : link
            };

            function controller($scope){
                var lastSlideIndex;
                var currentImage;

                var rowSize = $scope.ionGalleryRowSize;
                var zoomStart = false;

                $scope.selectedSlide = 1;
                $scope.hideAll = false;
                $scope.like = function(picture){
                    console.log('Likeit!');
                    var likeAction = 'like';
                    if(picture.liked){
                        likeAction = 'dislike';
                    }
                    Restangular
                    .all(likeAction+'/'+picture.id+'/.json')
                    .customGET("")
                    .then(function(response) {
                        picture.liked = response.liked;
                        picture.likes = response.qtd;
                        if(response.liked){
                            $scope.$parent.$parent.$parent.likes[picture.id] = picture;
                        } else {
                            delete $scope.$parent.$parent.$parent.likes[picture.id];
                        }
                    });
                };
                $scope.download = function(picture){
                    console.log('download', picture);
                    var file = picture.picture_url;

                    var options = {
                        location: 'yes',
                        clearcache: 'yes',
                        toolbar: 'yes'
                    };
                    $cordovaInAppBrowser.open(file, '_system', options)
                    .then(function(event) {
                        // success
                    })
                    .catch(function(event) {
                        // error
                    });
                };
                $scope.share = function(picture){
                    $ionicLoading.show();
                    var file = picture.picture_url;
                    $cordovaSocialSharing
                    .share(null, null, file, null)
                    .then(function(result) {
                        $ionicLoading.hide();
                    }, function(err) {
                        $ionicLoading.hide();
                    });

                }

                $scope.showImage = function(index) {
                    $scope.slides = [];
                    index++;
                    currentImage = index;
                    var galleryLength = $scope.ionGalleryItems.length;
                    var previndex = index - 1 < 0 ? galleryLength - 1 : index - 1;
                    var nextindex = index + 1 >= galleryLength ? 0 : index + 1;
                    $scope.slides[0] = $scope.ionGalleryItems[previndex];
                    $scope.slides[1] = $scope.ionGalleryItems[index];
                    $scope.slides[2] = $scope.ionGalleryItems[nextindex];
                    console.log($scope.ionGalleryItems);

                    lastSlideIndex = 1;
                    $scope.loadModal();
                };
                $scope.$on('openGaleria', function(event, obj) {
                    $scope.showImage(-1);
                })

                $scope.slideChanged = function(currentSlideIndex) {

                    if(currentSlideIndex === lastSlideIndex){
                        return;
                    }

                    var slideToLoad = $scope.slides.length - lastSlideIndex - currentSlideIndex;
                    var galleryLength = $scope.ionGalleryItems.length;
                    var imageToLoad;
                    var slidePosition = lastSlideIndex + '>' + currentSlideIndex;

                    if(slidePosition === '0>1' || slidePosition === '1>2' || slidePosition === '2>0'){
                        currentImage++;

                        if(currentImage >= galleryLength){
                            currentImage = 0;
                        }

                        imageToLoad = currentImage + 1;

                        if( imageToLoad >= galleryLength){
                            imageToLoad = 0;
                        }
                    }
                    else if(slidePosition === '0>2' || slidePosition === '1>0' || slidePosition === '2>1'){
                        currentImage--;

                        if(currentImage < 0){
                            currentImage = galleryLength - 1 ;
                        }

                        imageToLoad = currentImage - 1;

                        if(imageToLoad < 0){
                            imageToLoad = galleryLength - 1;
                        }
                    }

                    //Clear zoom
                    $ionicScrollDelegate.$getByHandle('slide-' + slideToLoad).zoomTo(1);

                    $scope.slides[slideToLoad] = $scope.ionGalleryItems[imageToLoad];

                    lastSlideIndex = currentSlideIndex;
                };

                $scope.$on('ZoomStarted', function(e){
                    $timeout(function () {
                        zoomStart = true;
                        $scope.hideAll = true;
                    });

                });

                $scope.$on('TapEvent', function(e){
                    $timeout(function () {
                        _onTap();
                    });

                });

                $scope.$on('DoubleTapEvent', function(event,position){
                    $timeout(function () {
                        _onDoubleTap(position);
                    });

                });

                var _onTap = function _onTap(){

                    if(zoomStart === true){
                        $ionicScrollDelegate.$getByHandle('slide-'+lastSlideIndex).zoomTo(1,true);

                        $timeout(function () {
                            _isOriginalSize();
                        },300);

                        return;
                    }

                    if(($scope.hasOwnProperty('ionSliderToggle') && $scope.ionSliderToggle === false && $scope.hideAll === false) || zoomStart === true){
                        return;
                    }

                    $scope.hideAll = !$scope.hideAll;
                };

                var _onDoubleTap = function _onDoubleTap(position){
                    if(zoomStart === false){
                        $ionicScrollDelegate.$getByHandle('slide-'+lastSlideIndex).zoomTo(3,true,position.x,position.y);
                        zoomStart = true;
                        $scope.hideAll = true;
                    }
                    else{
                        _onTap();
                    }
                };

                function _isOriginalSize(){
                    zoomStart = false;
                    _onTap();
                }

            }

            function link(scope, element, attrs) {
                var _modal;

                scope.loadModal = function(){

                    $ionicModal.fromTemplateUrl('app/components/ion-gallery/slider.html', {
                        scope: scope,
                        animation: 'fade-in'
                    }).then(function(modal) {
                        _modal = modal;
                        scope.openModal();
                    });
                };

                scope.openModal = function() {
                    _modal.show();
                };

                scope.closeModal = function() {
                    _modal.hide();
                };

                scope.$on('$destroy', function() {
                    _modal.remove();
                });


            }
        }
    })();
    angular.module("templates", []).run(["$templateCache", function($templateCache) {$templateCache.put("gallery.html","<div class=\"gallery-view\">\n  <div class=\"row\" ng-repeat=\"item in items track by $index\" ion-row-height>\n    <div ng-repeat=\"photo in item track by $index\"\n         class=\"col col-{{responsiveGrid}} image-container\">\n      \n      <img ion-image-scale\n           ng-src=\"{{photo.thumb}}\"\n           ng-click=\"showImage({{photo.position}})\">\n      \n    </div>\n  </div>\n  <div ion-slider></div>\n</div>");
    $templateCache.put("slider.html","<ion-modal-view class=\"imageView\">\n  <ion-header-bar class=\"headerView\" ng-show=\"!hideAll\">\n    <button class=\"button button-outline button-light close-btn\" ng-click=\"closeModal()\">{{::actionLabel}}</button>\n  </ion-header-bar>\n    \n  <ion-content class=\"has-no-header\" scroll=\"false\">\n    <ion-slide-box does-continue=\"true\" active-slide=\"selectedSlide\" show-pager=\"false\" class=\"listContainer\" on-slide-changed=\"slideChanged($index)\">\n      <ion-slide ng-repeat=\"single in slides track by $index\">\n        <ion-scroll direction=\"xy\"\n                    locking=\"false\" \n                    zooming=\"true\"\n                    min-zoom=\"1\"\n                    scrollbar-x=\"false\"\n                    scrollbar-y=\"false\"\n                    ion-slide-action\n                    delegate-handle=\"slide-{{$index}}\"\n                    overflow-scroll=\"false\"\n                    >\n        <div class=\"item item-image gallery-slide-view\">\n          {{single}} <img ng-src=\"{{single.src}}\">\n        </div>\n        <div ng-if=\"single.sub.length > 0\" class=\"image-subtitle\" ng-show=\"!hideAll\">\n            <span ng-bind-html=\'single.sub\'></span>\n        </div>\n        </ion-scroll>\n      </ion-slide>\n    </ion-slide-box>\n  </ion-content>\n</ion-modal-view>");}]);
