/**
* Authentication service.
*
* @author    Martin Micunda {@link http://martinmicunda.com}
* @copyright Copyright (c) 2015, Martin Micunda
* @license   The MIT License {@link http://opensource.org/licenses/MIT}
*/
(function () {
    'use strict';

    /**
    * @ngInject
    */
    function AuthenticationProvider() {
        this.$get = function($http, Restangular, Token, localStorageService) {

            var currentUser = null;

            function saveUserAndToken(token) {
                console.log('saveUserAndToken', token)
                Token.set(token);
                currentUser = Token.decodeToken(token);
                localStorageService.set('user', currentUser);
            }

            return {
                signup: function(params) {
                    console.log('auth signup', params);
                    return Restangular
                    .one('registrar.json')
                    .customPOST(params)
                    .then(function(response) {
                        //saveUserAndToken(response.data.token);
                        console.log('auth signup response', response);
                        return response;
                    });
                },
                signin: function(params) {
                    return Restangular
                    .all('api/users/token.json')
                    .post(params)
                    .then(function(response) {
                        saveUserAndToken(response.data.token);
                    });
                },
                recovery: function(params) {
                    return Restangular
                    .all('esqueci.json')
                    .post(params)
                    .then(function(response) {
                        return response;
                    });
                },
                signout: function() {
                    currentUser = null;
                    Token.remove();
                    localStorageService.remove('user');
                    /*return Restangular
                    .one('api/auth/signout')
                    .get()
                    .then(function(){
                        currentUser = null;
                        Token.remove();
                    });*/
                },
                isAuthenticated: function() {
                    if(!Token.get()){
                        return false;
                    }
                    console.log('Token', Token.decodeToken( Token.get()))
                    console.log('isAuthenticated', angular.toJson(this.getCurrentUser()) == angular.toJson( Token.decodeToken( Token.get()) ));
                    return angular.toJson(this.getCurrentUser()) == angular.toJson( Token.decodeToken( Token.get()) );
                },
                getCurrentUser: function() {
                    return currentUser || localStorageService.get('user')
                }
            };
        };
    }

    angular
    .module('app.core')
    .provider('Authentication', AuthenticationProvider);
})();
