/**
 * Authentication interceptor.
 *
 * @author    Martin Micunda {@link http://martinmicunda.com}
 * @copyright Copyright (c) 2015, Martin Micunda
 * @license   The MIT License {@link http://opensource.org/licenses/MIT}
 */
(function () {
    'use strict';

    /**
     * @description
     * The http interceptor that listens for errors.
     *
     * @param $q
     * @param $cordovaDialogs
     * @returns {{responseError: responseError}}
     * @constructor
     * @ngInject
     */
    function ErrorInterceptor($q, $cordovaDialogs) {
        return {
            responseError: function (rejection) {
                if(rejection != null && rejection.status === 401) {
                    $cordovaDialogs.alert('CPF / Senha inválidos.', 'Erro', 'OK');
                    //$ionicPopup.alert({title: 'Erro..', template: 'CPF / Senha inválidos. Tente novamente!'});
                } else if(rejection != null && rejection.status === 0) {
                    $cordovaDialogs.alert('Sem acesso ao servidor. Confira sua conexão e tente novamente!', 'Erro..', 'OK');
                    //$ionicPopup.alert({title: 'Erro..', template: 'Sem acesso ao servidor. Confira sua conexão e tente novamente!'});
                } else if(rejection != null ) {
                    $cordovaDialogs.alert('Tente novamente! COD#'+rejection.status, 'Erro..', 'OK');
                    //$ionicPopup.alert({title: 'Erro..', template: 'Tente novamente! COD#'+rejection.status});
                }
                return $q.reject(rejection);
            }
        };
    }

    angular
        .module('app.core')
        .factory('ErrorInterceptor', ErrorInterceptor)
        .config(function ($httpProvider) {
            // we have to add the interceptor to the queue as a string because the interceptor depends upon service instances that are not available in the config block.
            $httpProvider.interceptors.push('ErrorInterceptor');
        });
})();
