/**
* Signin controller.
*
* @author    Martin Micunda {@link http://martinmicunda.com}
* @copyright Copyright (c) 2015, Martin Micunda
* @license   The MIT License {@link http://opensource.org/licenses/MIT}
*/
(function () {
    'use strict';

    /**
    * @ngdoc controller
    * @name SigninCtrl
    * @module app.signin
    * @requires $rootScope
    * @requires $state
    * @requires Authentication
    * @requires $cordovaVibration
    * @description
    * Controller for the signin page.
    *
    * @ngInject
    */

    function SigninCtrl($rootScope, $state, Authentication, $ionicHistory, $ionicLoading, $cordovaStatusbar) {
        var vm = this;
        vm.credentials = {cpf:'',password:''};
        vm.signIn = function(credentials, isValid) {
            if(!isValid) {return;}

            $ionicLoading.show();

            Authentication.signin(credentials).then(function () {
                // save user profile details to $rootScope
                if (window.StatusBar) {
                    //$cordovaStatusbar.overlaysWebView(true); //red
                    //$cordovaStatusbar.style(0);
                    $cordovaStatusbar.styleHex('#bbb');                    
                }

                $ionicLoading.hide();
                $rootScope.me = Authentication.getCurrentUser();

                $state.go('app.home', { userId: $rootScope.me._id});
            }, function(error) {
                $ionicLoading.hide();
                console.log('error ' + JSON.stringify(error));
            });
        };
        vm.goToSignup = function(){
            $ionicHistory.nextViewOptions({
                disableBack: true
            });
            $state.go('signup');
        };

        vm.goToRecovery = function(){
            /*$ionicHistory.nextViewOptions({
                disableBack: true
            });*/
            $state.go('recovery');
        };

        vm.goToTerms = function() {
            $rootScope.terms();
        }
    }

    angular
    .module('app.signin')
    .controller('SigninCtrl', SigninCtrl);
})();
